@@ -45,8 +45,7 @@ def comb_df_by_group(df, group_names):
             combined_values.append(df[col].values.tolist())
         comb_list = [
             item for sublist in combined_values for item in sublist]
-        df = pd.DataFrame(comb_list, columns=[group])
-        df_comb = pd.concat([df_comb, df], axis=1)
+        df_comb.loc[:, group] = pd.Series(comb_list)
 
     return df_comb
 
